@@ -1,4 +1,4 @@
-#![forbid(unsafe_code)]
+#![deny(unsafe_code)]
 
 #[macro_use]
 extern crate log;
@@ -12,7 +12,6 @@ pub mod database;
 pub mod encryption;
 pub mod history;
 pub mod import;
-pub mod kv;
 pub mod login;
 pub mod logout;
 pub mod ordering;
