@@ -11,9 +11,9 @@ use eyre::{Context, Result};
 use runtime_format::{FormatKey, FormatKeyError, ParseSegment, ParsedFmt};
 
 use atuin_client::{
-    database::{current_context, Database, Sqlite},
+    database::{Database, Sqlite, current_context},
     encryption,
-    history::{store::HistoryStore, History},
+    history::{History, store::HistoryStore},
     record::sqlite_store::SqliteStore,
     settings::{
         FilterMode::{Directory, Global, Session},
@@ -25,7 +25,7 @@ use atuin_client::{
 use atuin_client::{record, sync};
 
 use log::{debug, warn};
-use time::{macros::format_description, OffsetDateTime};
+use time::{OffsetDateTime, macros::format_description};
 
 use super::search::format_duration_into;
 
@@ -117,6 +117,21 @@ pub enum Cmd {
         #[arg(short = 'n', long)]
         dry_run: bool,
     },
+
+    /// Delete duplicate history entries (that have the same command, cwd and hostname)
+    Dedup {
+        /// List matching history lines without performing the actual deletion.
+        #[arg(short = 'n', long)]
+        dry_run: bool,
+
+        /// Only delete results added before this date
+        #[arg(long, short)]
+        before: String,
+
+        /// How many recent duplicates to keep
+        #[arg(long)]
+        dupkeep: u32,
+    },
 }
 
 #[derive(Clone, Copy, Debug)]
@@ -285,7 +300,9 @@ fn parse_fmt(format: &str) -> ParsedFmt {
         Ok(fmt) => fmt,
         Err(err) => {
             eprintln!("ERROR: History formatting failed with the following error: {err}");
-            println!("If your formatting string contains curly braces (eg: {{var}}) you need to escape them this way: {{{{var}}.");
+            println!(
+                "If your formatting string contains curly braces (eg: {{var}}) you need to escape them this way: {{{{var}}."
+            );
             std::process::exit(1)
         }
     }
@@ -542,6 +559,54 @@ impl Cmd {
         Ok(())
     }
 
+    async fn handle_dedup(
+        db: &impl Database,
+        settings: &Settings,
+        store: SqliteStore,
+        before: i64,
+        dupkeep: u32,
+        dry_run: bool,
+    ) -> Result<()> {
+        let matches: Vec<History> = db.get_dups(before, dupkeep).await?;
+
+        match matches.len() {
+            0 => {
+                println!("No duplicates to delete.");
+                return Ok(());
+            }
+            1 => println!("Found 1 duplicate to delete."),
+            n => println!("Found {n} duplicates to delete."),
+        }
+
+        if dry_run {
+            print_list(
+                &matches,
+                ListMode::Human,
+                Some(settings.history_format.as_str()),
+                false,
+                false,
+                settings.timezone,
+            );
+        } else {
+            let encryption_key: [u8; 32] = encryption::load_key(settings)
+                .context("could not load encryption key")?
+                .into();
+            let host_id = Settings::host_id().expect("failed to get host_id");
+            let history_store = HistoryStore::new(store.clone(), host_id, encryption_key);
+
+            for entry in matches {
+                eprintln!("deleting {}", entry.id);
+                if settings.sync.records {
+                    let (id, _) = history_store.delete(entry.id).await?;
+                    history_store.incremental_build(db, &[id]).await?;
+                } else {
+                    db.delete(entry).await?;
+                }
+            }
+        }
+        Ok(())
+    }
+
     pub async fn run(self, settings: &Settings) -> Result<()> {
         let context = current_context();
 
@@ -550,11 +615,11 @@ impl Cmd {
         if settings.daemon.enabled {
             match self {
                 Self::Start { command } => {
-                    return Self::handle_daemon_start(settings, &command).await
+                    return Self::handle_daemon_start(settings, &command).await;
                 }
 
                 Self::End { id, exit, duration } => {
-                    return Self::handle_daemon_end(settings, &id, exit, duration).await
+                    return Self::handle_daemon_end(settings, &id, exit, duration).await;
                 }
 
                 _ => {}
@@ -604,7 +669,7 @@ impl Cmd {
                 format,
             } => {
                 let last = db.last().await?;
-                let last = last.as_ref().map(std::slice::from_ref).unwrap_or_default();
+                let last = last.as_slice();
                 let tz = timezone.unwrap_or(settings.timezone);
                 print_list(
                     last,
@@ -626,6 +691,22 @@ impl Cmd {
             Self::Prune { dry_run } => {
                 Self::handle_prune(&db, settings, store, context, dry_run).await
             }
+
+            Self::Dedup {
+                dry_run,
+                before,
+                dupkeep,
+            } => {
+                let before = i64::try_from(
+                    interim::parse_date_string(
+                        before.as_str(),
+                        OffsetDateTime::now_utc(),
+                        interim::Dialect::Uk,
+                    )?
+                    .unix_timestamp_nanos(),
+                )?;
+                Self::handle_dedup(&db, settings, store, before, dupkeep, dry_run).await
+            }
         }
     }
 }
